.. _pythonapi:

================
Input Definition
================

Full API documentation.


Defining materials
------------------

.. autosummary::
   :toctree: generated
   :nosignatures:
   :template: omcfunction.rst

   mcdc.material
   mcdc.nuclide


Defining geometry
-----------------

.. autosummary::
   :toctree: generated
   :nosignatures:
   :template: omcfunction.rst

   mcdc.surface
   mcdc.cell
   mcdc.universe
   mcdc.lattice
   


Defining simulation
-------------------

.. autosummary::
   :toctree: generated
   :nosignatures:
   :template: omcfunction.rst

   mcdc.source
   mcdc.tally
   mcdc.eigenmode
   mcdc.setting



Defining techniques
-------------------

.. autosummary::
   :toctree: generated
   :nosignatures:
   :template: omcfunction.rst

   mcdc.implicit_capture
   mcdc.weighted_emission
   mcdc.population_control
   mcdc.branchless_collision
   mcdc.time_census
   mcdc.weight_window
   mcdc.iQMC
   mcdc.weight_roulette
   mcdc.IC_generator
   mcdc.dsm





